summaryrefslogtreecommitdiffstats
path: root/sys/i386/isa/atapi.c
diff options
context:
space:
mode:
authorsos <sos@FreeBSD.org>1998-12-27 17:12:02 +0000
committersos <sos@FreeBSD.org>1998-12-27 17:12:02 +0000
commit8214ce6ac3a4ee52f740c53bfcbdd2d5e05b0a1e (patch)
tree23f0d975b23bad2804d9ee5099d01e9a6553c434 /sys/i386/isa/atapi.c
parent58ce405aac26d60e4ff67cfaf739c559872679ee (diff)
downloadFreeBSD-src-8214ce6ac3a4ee52f740c53bfcbdd2d5e05b0a1e.zip
FreeBSD-src-8214ce6ac3a4ee52f740c53bfcbdd2d5e05b0a1e.tar.gz
Fix breakage by cleanup.
Diffstat (limited to 'sys/i386/isa/atapi.c')
-rw-r--r--sys/i386/isa/atapi.c16
1 files changed, 3 insertions, 13 deletions
diff --git a/sys/i386/isa/atapi.c b/sys/i386/isa/atapi.c
index 964a3ae..9b3090d 100644
--- a/sys/i386/isa/atapi.c
+++ b/sys/i386/isa/atapi.c
@@ -88,7 +88,7 @@
* You will need to make at least three routines: open(), close(),
* strategy() and possibly ioctl().
* 2. Make attach() routine, which should allocate all the needed data
- * structures and print the device description string (see wcdattach()).
+ * structures and print the device description string (see xxxattach()).
* 3. Add an appropriate case to the switch in atapi_attach() routine,
* call attach() routine of the new driver here. Add the appropriate
* #include line at the top of attach.c.
@@ -104,7 +104,6 @@
#ifndef ATAPI_MODULE
# include "acd.h"
-# include "wcd.h"
# include "wfd.h"
# include "wst.h"
/* # include "wmd.h" -- add your driver here */
@@ -172,7 +171,6 @@ static int atapi_wait_cmd (struct atapi *ata, struct atapicmd *ac);
extern int wdstart (int ctrlr);
extern int acdattach(struct atapi*, int, struct atapi_params*, int);
-extern int wcdattach(struct atapi*, int, struct atapi_params*, int);
extern int wfdattach(struct atapi*, int, struct atapi_params*, int);
extern int wstattach(struct atapi*, int, struct atapi_params*, int);
@@ -302,17 +300,9 @@ int atapi_attach (int ctlr, int unit, int port)
ata->attached[unit] = 1;
return (1);
#else
-#if NWCD > 0
- /* ATAPI CD-ROM drives */
- if (wcdattach (ata, unit, ap, ata->debug) < 0)
- break;
- ata->attached[unit] = 1;
- return (1);
-#else
printf ("wdc%d: ATAPI CD-ROMs not configured\n", ctlr);
break;
#endif
-#endif
case AT_TYPE_TAPE: /* streaming tape */
#if NWST > 0
@@ -662,8 +652,8 @@ int atapi_start_cmd (struct atapi *ata, struct atapicmd *ac)
*/
int atapi_wait_cmd (struct atapi *ata, struct atapicmd *ac)
{
- /* Wait for DRQ from 50 usec to 3 msec for slow devices */
- int cnt = ata->intrcmd ? 10000 : ata->slow ? 3000 : 50;
+ /* Wait for DRQ from 100 usec to 3 msec for slow devices */
+ int cnt = ata->intrcmd ? 10000 : ata->slow ? 3000 : 100;
int ireason = 0, phase = 0;
/* Wait for command phase. */
OpenPOWER on IntegriCloud